==> content_connected-2.1.1.tar.gz: content_connected/src/Controller/ContentConnectedController.php <==
<?php

namespace Drupal\content_connected\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\node\NodeTypeInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\content_connected\ContentConnectedManagerInterface;
use Drupal\Core\Entity\EntityTypeManager;

/**
 * Implements Class ContentConnectedController.
 *
 * @package Drupal\content_connected\Controller
 */
class ContentConnectedController extends ControllerBase {

  /**
   * The contentconnected manager.
   *
   * @var \Drupal\content_connected\ContentConnectedManagerInterface
   */
  protected $contentConnectedmanager;

  /**
   * Entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManager
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(ContentConnectedManagerInterface $content_connected_manager, EntityTypeManager $entity_type_manager) {
    $this->contentConnectedmanager = $content_connected_manager;
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
     $container->get('content_connected.manager'),
     $container->get('entity_type.manager')
    );
  }

  /**
   * Contentconnectedcontroller.
   *
   * @return string
   *   Return table of matching.
   */
  public function contentConnectedoverview($node) {
    return [
      '#type' => 'markup',
      '#markup' => $this->contentConnectedmanager->renderMatches($node),
    ];
  }

  /**
   * The _title_callback for the entity.node.content_connected route.
   *
   * @param \Drupal\node\NodeTypeInterface $node
   *   The current node.
   *
   * @return string
   *   The page title.
   */
  public function addPageTitle(NodeTypeInterface $node) {
    $node_storage = $this->entityTypeManager->getStorage('node')->load($node);
    return $this->t('Content connected with @name', ['@name' => $node_storage->label()]);
  }

}

==> content_connected-2.1.2.tar.gz: content_connected/src/Controller/ContentConnectedController.php <==
<?php

namespace Drupal\content_connected\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\node\NodeTypeInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\content_connected\ContentConnectedManagerInterface;
use Drupal\Core\Entity\EntityTypeManager;

/**
 * Implements Class ContentConnectedController.
 *
 * @package Drupal\content_connected\Controller
 */
class ContentConnectedController extends ControllerBase {

  /**
   * The contentconnected manager.
   *
   * @var \Drupal\content_connected\ContentConnectedManagerInterface
   */
  protected $contentConnectedmanager;

  /**
   * Entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManager
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(ContentConnectedManagerInterface $content_connected_manager, EntityTypeManager $entity_type_manager) {
    $this->contentConnectedmanager = $content_connected_manager;
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
     $container->get('content_connected.manager'),
     $container->get('entity_type.manager')
    );
  }

  /**
   * Contentconnectedcontroller.
   *
   * @return string
   *   Return table of matching.
   */
  public function contentConnectedoverview($node) {
    return [
      '#type' => 'markup',
      '#markup' => $this->contentConnectedmanager->renderMatches($node),
    ];
  }

  /**
   * The _title_callback for the entity.node.content_connected route.
   *
   * @param \Drupal\node\NodeTypeInterface|string $node
   *   The current node.
   *
   * @return string
   *   The page title.
   */
  public function addPageTitle(NodeTypeInterface|string $node) {
    $node_storage = $this->entityTypeManager->getStorage('node')->load($node);
    return $this->t('Content connected with @name', ['@name' => $node_storage->label()]);
  }

}
